[gnus git] branch master updated: m0-11-99-g1d11306 =2= registry.el (registry-db): Set default slot later ; * gnus-art.el: Fix up compiler warnings

Katsumi <[email protected]> Thu, 18 Dec 2014 23:47:46 +0100
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  1d113068206db537f062ef9a1c3f38de98797200 (commit)
       via  2b20527a87e8e056ed22892bd6e0d249424a0403 (commit)
      from  3322b953e78d1714443478d212c633874226d190 (commit)


- Log -----------------------------------------------------------------
commit 1d113068206db537f062ef9a1c3f38de98797200
Author: Paul Eggert <[email protected]>
Date:   Thu Dec 18 22:47:26 2014 +0000

    registry.el (registry-db): Set default slot later

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index d476e2a..5f25801 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,8 @@
+2014-12-18  Paul Eggert  <[email protected]>
+
+	* registry.el (registry-db): Set default slot later.
+	This is because its value is not a literal integer.
+
 2014-12-18  Teodor Zlatanov  <[email protected]>
 
 	* registry.el (registry-db): Fix default registry-db max-size.
diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 072dd08..d476e2a 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -2,6 +2,30 @@
 
 	* registry.el (registry-db): Fix default registry-db max-size.
 
+2014-12-18  Stefan Monnier  <[email protected]>
+
+	* mm-util.el (mm-with-unibyte-current-buffer): Mark obsolete and
+	add warning.
+
+	* gnus-art.el: Fix up compiler warnings.
+	(article-display-face, article-display-x-face): Remove unused `face'.
+	(gnus-article-browse-html-save-cid-content): Remove unused var `type'.
+	(article-date-ut): Remove unused var `first'.
+	(gnus-article-prepare): Remove unused var `gnus-article'.
+	(gnus-mime-save-part-and-strip): Remove unused var `param'.
+	(gnus-mime-inline-part): Remove unused vars `charset', `contents', and
+	`coding-system' along with corresponding dead code.
+	(gnus-mime-view-part-externally): Remove unused var
+	`mm-user-display-methods'.
+	(gnus-insert-mime-button): Let-bind gnus-tmp-id explicitly.
+	(gnus-display-mime): Remove unused var `handle'.
+	(gnus-mime-display-alternative): Remove unused var `props'.
+	(gnus-article-read-summary-keys): Remove unused var `up-to-top'.
+	(gnus-article-edit-done): Remove unused var `p'.
+	(gnus-url-mailto): Remove unused var `to'.
+	(gnus-treat-article): Let-bind gnus-treat-condition, part-number,
+	total-parts, and gnus-treat-type explicitly.  Remove unused var `elem'.
+
 2014-12-18  Eric Abrahamsen  <[email protected]>
 
 	* registry.el (registry-db): Consolidate the :max-hard and :max-soft
diff --git a/lisp/gnus-art.el b/lisp/gnus-art.el
index 15f6ffc..aa041aa 100644
--- a/lisp/gnus-art.el
+++ b/lisp/gnus-art.el
@@ -1627,6 +1627,8 @@ It is a string, such as \"PGP\". If nil, ask user."
   :type 'string
   :group 'mime-security)
 
+(defvar idna-program)
+
 (defcustom gnus-use-idna (and (condition-case nil (require 'idna) (file-error))
 			      (mm-coding-system-p 'utf-8)
 			      idna-program
@@ -1842,7 +1844,7 @@ Initialized from `text-mode-syntax-table.")
 	(incf i)))
       i))
 
-(defun article-hide-headers (&optional arg delete)
+(defun article-hide-headers (&optional _arg _delete)
   "Hide unwanted headers and possibly sort them as well."
   (interactive)
   ;; This function might be inhibited.
@@ -2412,7 +2414,7 @@ long lines if and only if arg is positive."
       (if (and wash-face-p (memq 'face gnus-article-wash-types))
 	  (gnus-delete-images 'face)
 	(let ((from (message-fetch-field "from"))
-	      face faces)
+	      faces)
 	  (save-current-buffer
 	    (when (and wash-face-p
 		       (gnus-buffer-live-p gnus-original-article-buffer)
@@ -2462,7 +2464,7 @@ long lines if and only if arg is positive."
 	  (gnus-delete-images 'xface)
 	;; Display X-Faces.
 	(let ((from (message-fetch-field "from"))
-	      x-faces face)
+	      x-faces)
 	  (save-current-buffer
 	    (when (and wash-face-p
 		       (gnus-buffer-live-p gnus-original-article-buffer)
@@ -2795,7 +2797,7 @@ summary buffer."
   "Find CID content in HANDLES and save it in a file in DIRECTORY.
 Return file name."
   (save-match-data
-    (let (file type)
+    (let (file)
       (catch 'found
 	(dolist (handle handles)
 	  (cond
@@ -3397,7 +3399,7 @@ means show, 0 means toggle."
 	'hidden
       nil)))
 
-(defun gnus-article-show-hidden-text (type &optional dummy)
+(defun gnus-article-show-hidden-text (type &optional _dummy)
   "Show all hidden text of type TYPE.
 Originally it is hide instead of DUMMY."
   (let ((inhibit-read-only t)
@@ -3436,7 +3438,7 @@ lines forward."
 		     gnus-article-date-headers)
 		   t))
 
-(defun article-date-ut (&optional type highlight date-position)
+(defun article-date-ut (&optional type _highlight date-position)
   "Convert DATE date to TYPE in the current article.
 The default type is `ut'.  See `gnus-article-date-headers' for
 possible values."
@@ -3444,7 +3446,6 @@ possible values."
   (let* ((case-fold-search t)
 	 (inhibit-read-only t)
 	 (inhibit-point-motion-hooks t)
-	 (first t)
 	 (visible-date (mail-fetch-field "Date"))
 	 pos date bface eface)
     (save-excursion
@@ -3983,7 +3984,7 @@ This format is defined by the `gnus-article-time-format' variable."
       (set dir-var (file-name-directory result)))
     result))
 
-(defun gnus-article-archive-name (group)
+(defun gnus-article-archive-name (_group)
   "Return the first instance of an \"Archive-name\" in the current buffer."
   (let ((case-fold-search t))
     (when (re-search-forward "archive-name: *\\([^ \n\t]+\\)[ \t]*$" nil t)
@@ -4215,7 +4216,7 @@ If variable `gnus-use-long-file-name' is non-nil, it is
 	default
       (or last-file default))))
 
-(defun gnus-plain-save-name (newsgroup headers &optional last-file)
+(defun gnus-plain-save-name (newsgroup _headers &optional last-file)
   "Generate file name from NEWSGROUP, HEADERS, and optional LAST-FILE.
 If variable `gnus-use-long-file-name' is non-nil, it is
 ~/News/news.group.  Otherwise, it is like ~/News/news/group/news."
@@ -4228,7 +4229,7 @@ If variable `gnus-use-long-file-name' is non-nil, it is
 	  default-directory))
        gnus-article-save-directory)))
 
-(defun gnus-sender-save-name (newsgroup headers &optional last-file)
+(defun gnus-sender-save-name (_newsgroup headers &optional _last-file)
   "Generate file name from sender."
   (let ((from (mail-header-from headers)))
     (expand-file-name
@@ -4425,6 +4426,8 @@ If variable `gnus-use-long-file-name' is non-nil, it is
 (substitute-key-definition
  'undefined 'gnus-article-read-summary-keys gnus-article-mode-map)
 
+(defvar gnus-article-send-map)
+
 (gnus-define-keys (gnus-article-send-map "S" gnus-article-mode-map)
   "W" gnus-article-wide-reply-with-original)
 (if (featurep 'xemacs)
@@ -4608,18 +4611,19 @@ commands:
 	   (forward-line line)
 	   (point)))))))
 
-(defun gnus-article-prepare (article &optional all-headers header)
+(defvar gnus-tmp-internal-hook)
+
+(defun gnus-article-prepare (article &optional all-headers _header)
   "Prepare ARTICLE in article mode buffer.
 ARTICLE should either be an article number or a Message-ID.
 If ARTICLE is an id, HEADER should be the article headers.
 If ALL-HEADERS is non-nil, no headers are hidden."
-  (save-excursion
+  (save-excursion                ;FIXME: Shouldn't that be save-current-buffer?
     ;; Make sure we start in a summary buffer.
     (unless (derived-mode-p 'gnus-summary-mode)
       (set-buffer gnus-summary-buffer))
     (setq gnus-summary-buffer (current-buffer))
-    (let* ((gnus-article (if header (mail-header-number header) article))
-	   (summary-buffer (current-buffer))
+    (let* ((summary-buffer (current-buffer))
 	   (gnus-tmp-internal-hook gnus-article-internal-prepare-hook)
 	   (group gnus-newsgroup-name)
 	   result)
@@ -4718,6 +4722,8 @@ If ALL-HEADERS is non-nil, no headers are hidden."
 	    (gnus-run-hooks 'gnus-article-prepare-hook)
 	    t))))))
 
+(defvar gnus-mime-display-attachment-buttons-in-header)
+
 ;;;###autoload
 (defun gnus-article-prepare-display ()
   "Make the current buffer look like a nice article."
@@ -4841,6 +4847,16 @@ Valid specifiers include:
 General format specifiers can also be used.  See Info node
 `(gnus)Formatting Variables'.")
 
+(defvar gnus-tmp-type)
+(defvar gnus-tmp-type-long)
+(defvar gnus-tmp-name)
+(defvar gnus-tmp-description)
+(defvar gnus-tmp-id)
+(defvar gnus-tmp-length)
+(defvar gnus-tmp-dots)
+(defvar gnus-tmp-info)
+(defvar gnus-tmp-pressed-details)
+
 (defvar gnus-mime-button-line-format-alist
   '((?t gnus-tmp-type ?s)
     (?T gnus-tmp-type-long ?s)
@@ -5067,7 +5083,6 @@ If FILE is given, use it for the external part."
 The current article has a complicated MIME structure, giving up..."))
   (let* ((data (get-text-property (point) 'gnus-data))
 	 (id (get-text-property (point) 'gnus-part))
-	 param
 	 (handles gnus-article-mime-handles))
     (unless file
       (setq file
@@ -5325,7 +5340,7 @@ Compressed files like .gz and .bz2 are decompressed."
 		    (text-property-any (point-min) (point) 'gnus-data handle)))
 	    (setq handle (get-text-property b 'gnus-data))
 	    b))
-	 start contents charset coding-system)
+	 start)
     (when handle
       (when (= b (prog1
 		     btn
@@ -5336,27 +5351,11 @@ Compressed files like .gz and .bz2 are decompressed."
 	(setq b btn))
       (if (and (not arg) (mm-handle-undisplayer handle))
 	  (mm-remove-part handle)
-	(mm-with-unibyte-buffer
-	  (mm-insert-part handle)
-	  (setq contents
-		(or (mm-decompress-buffer (mm-handle-filename handle) nil t)
-		    (buffer-string))))
 	(cond
-	 ((not arg)
-	  (unless (setq charset (mail-content-type-get
-				 (mm-handle-type handle) 'charset))
-	    (unless (setq coding-system
-			  (mm-with-unibyte-buffer
-			    (insert contents)
-			    (mm-find-buffer-file-coding-system)))
-	      (setq charset gnus-newsgroup-charset))))
+	 ((not arg) nil)
 	 ((numberp arg)
 	  (if (mm-handle-undisplayer handle)
-	      (mm-remove-part handle))
-	  (setq charset
-		(or (cdr (assq arg
-			       gnus-summary-show-article-charset-alist))
-		    (mm-read-coding-system "Charset: "))))
+	      (mm-remove-part handle)))
 	 ((mm-handle-undisplayer handle)
 	  (mm-remove-part handle)))
 	(goto-char start)
@@ -5466,7 +5465,6 @@ specified charset."
   (interactive)
   (gnus-article-check-buffer)
   (let* ((handle (or handle (get-text-property (point) 'gnus-data)))
-	 (mm-user-display-methods nil)
 	 (mm-inlined-types nil)
 	 (mail-parse-charset gnus-newsgroup-charset)
 	 (mail-parse-ignored-charsets
@@ -5834,11 +5832,12 @@ all parts."
     (when gnus-break-pages
       (gnus-narrow-to-page))))
 
-(defun gnus-insert-mime-button (handle gnus-tmp-id &optional displayed)
+(defun gnus-insert-mime-button (handle id &optional displayed)
   (let ((gnus-tmp-name
 	 (or (mm-handle-filename handle)
 	     (mail-content-type-get (mm-handle-type handle) 'url)
 	     ""))
+        (gnus-tmp-id id)
 	(gnus-tmp-type (mm-handle-media-type handle))
 	(gnus-tmp-description (or (mm-handle-description handle) ""))
 	(gnus-tmp-dots
@@ -5889,7 +5888,7 @@ all parts."
 	    "hide" "show")
 	(aref gnus-down-mouse-3 0))))))
 
-(defun gnus-widget-press-button (elems el)
+(defun gnus-widget-press-button (elems _el)
   (goto-char (widget-get elems :from))
   (gnus-article-press-button))
 
@@ -5907,8 +5906,7 @@ all parts."
 	  ;; may change the point.  So we set the window point.
 	  (set-window-point window point)))
       (let ((handles ihandles)
-	    (inhibit-read-only t)
-	    handle)
+	    (inhibit-read-only t))
 	(cond (handles)
 	      ((setq handles (mm-dissect-buffer nil gnus-article-loose-mime))
 	       (when gnus-article-emulate-mime
@@ -6140,7 +6138,7 @@ If nil, don't show those extra buttons."
   (let* ((preferred (or preferred (mm-preferred-alternative handles)))
 	 (ihandles handles)
 	 (point (point))
-	 handle (inhibit-read-only t) from props begend not-pref)
+	 handle (inhibit-read-only t) from begend not-pref)
     (save-window-excursion
       (save-restriction
 	(when ibegend
@@ -6627,6 +6625,8 @@ specifies."
 		      (if header-line-format 1 0)
 		      2)))))))
 
+(defvar scroll-in-place)
+
 (defun gnus-article-next-page-1 (lines)
   (condition-case ()
       (let ((scroll-in-place nil)
@@ -6714,7 +6714,9 @@ not have a face in `gnus-article-boring-faces'."
   (unless (derived-mode-p 'gnus-article-mode)
     (error "Command invoked outside of a Gnus article buffer")))
 
-(defun gnus-article-read-summary-keys (&optional arg key not-restore-window)
+(defvar gnus-pick-mode)
+
+(defun gnus-article-read-summary-keys (&optional _arg key not-restore-window)
   "Read a summary buffer key sequence and execute it from the article buffer."
   (interactive "P")
   (gnus-article-check-buffer)
@@ -6727,8 +6729,6 @@ not have a face in `gnus-article-boring-faces'."
 	   "An" "Ap" [?A (meta return)] [?A delete]))
 	(nosave-in-article
 	 '("AS" "\C-d"))
-	(up-to-top
-	 '("n" "Gn" "p" "Gp"))
 	keys new-sum-point)
     (with-current-buffer gnus-article-current-summary
       (let (gnus-pick-mode)
@@ -6887,6 +6887,7 @@ KEY is a string or a vector."
 (defvar gnus-agent-summary-mode)
 (defvar gnus-draft-mode)
 (defvar help-xref-stack-item)
+(defvar help-xref-following)
 
 (defun gnus-article-describe-bindings (&optional prefix)
   "Show a list of all defined keys, and their definitions.
@@ -7331,7 +7332,6 @@ groups."
   (let ((func gnus-article-edit-done-function)
 	(buf (current-buffer))
 	(start (window-start))
-	(p (point))
 	(winconf gnus-prev-winconf))
     (widen) ;; Widen it in case that users narrowed the buffer.
     (funcall func arg)
@@ -7960,7 +7960,7 @@ do the highlighting.  See the documentation for those functions."
   (gnus-article-add-buttons)
   (gnus-article-add-buttons-to-head))
 
-(defun gnus-article-highlight-some (&optional force)
+(defun gnus-article-highlight-some (&optional _force)
   "Highlight current article.
 This function calls `gnus-article-highlight-headers',
 `gnus-article-highlight-signature', and `gnus-article-add-buttons' to
@@ -8263,9 +8263,11 @@ url is put as the `gnus-button-url' overlay property on the button."
 	(error "Unknown news URL syntax"))))
     (list scheme server port group message-id articles)))
 
+(defvar nntp-port-number)
+
 (defun gnus-button-handle-news (url)
   "Fetch a news URL."
-  (destructuring-bind (scheme server port group message-id articles)
+  (destructuring-bind (_scheme server port group message-id _articles)
       (gnus-parse-news-url url)
     (cond
      (message-id
@@ -8387,7 +8389,7 @@ url is put as the `gnus-button-url' overlay property on the button."
   (with-current-buffer gnus-summary-buffer
     (gnus-summary-refer-article message-id)))
 
-(defun gnus-button-fetch-group (address &rest ignore)
+(defun gnus-button-fetch-group (address &rest _ignore)
   "Fetch GROUP specified by ADDRESS."
   (when (string-match "\\`\\(nntp\\|news\\):\\(//\\)?\\(.*\\)\\'"
 		      address)
@@ -8435,15 +8437,15 @@ url is put as the `gnus-button-url' overlay property on the button."
   (setq url (replace-regexp-in-string "\n" " " url))
   (when (string-match "mailto:/*\\(.*\\)" url)
     (setq url (substring url (match-beginning 1) nil)))
-  (let (to args subject func)
-    (setq args (gnus-url-parse-query-string
+  (let* ((args (gnus-url-parse-query-string
 		(if (string-match "^\\?" url)
 		    (substring url 1)
 		  (if (string-match "^\\([^?]+\\)\\?\\(.*\\)" url)
 		      (concat "to=" (match-string 1 url) "&"
 			      (match-string 2 url))
-		    (concat "to=" url))))
-	  subject (cdr-safe (assoc "subject" args)))
+		    (concat "to=" url)))))
+         (subject (cdr-safe (assoc "subject" args)))
+         func)
     (gnus-msg-mail)
     (while args
       (setq func (intern-soft (concat "message-goto-" (downcase (caar args)))))
@@ -8500,7 +8502,7 @@ url is put as the `gnus-button-url' overlay property on the button."
      :action 'gnus-button-prev-page
      :button-keymap gnus-prev-page-map)))
 
-(defun gnus-button-next-page (&optional args more-args)
+(defun gnus-button-next-page (&optional _args _more-args)
   "Go to the next page."
   (interactive)
   (let ((win (selected-window)))
@@ -8508,7 +8510,7 @@ url is put as the `gnus-button-url' overlay property on the button."
     (gnus-article-next-page)
     (select-window win)))
 
-(defun gnus-button-prev-page (&optional args more-args)
+(defun gnus-button-prev-page (&optional _args _more-args)
   "Go to the prev page."
   (interactive)
   (let ((win (selected-window)))
@@ -8536,7 +8538,7 @@ url is put as the `gnus-button-url' overlay property on the button."
      :action 'gnus-button-next-page
      :button-keymap gnus-next-page-map)))
 
-(defun gnus-article-button-next-page (arg)
+(defun gnus-article-button-next-page (_arg)
   "Go to the next page."
   (interactive "P")
   (let ((win (selected-window)))
@@ -8544,7 +8546,7 @@ url is put as the `gnus-button-url' overlay property on the button."
     (gnus-article-next-page)
     (select-window win)))
 
-(defun gnus-article-button-prev-page (arg)
+(defun gnus-article-button-prev-page (_arg)
   "Go to the prev page."
   (interactive "P")
   (let ((win (selected-window)))
@@ -8595,20 +8597,31 @@ For example:
 
 (defvar gnus-inhibit-article-treatments nil)
 
-(defun gnus-treat-article (gnus-treat-condition
-			   &optional part-number total-parts gnus-treat-type)
-  (let ((gnus-treat-length (- (point-max) (point-min)))
+;; Dynamic variables.
+(defvar part-number)                    ;FIXME: Lacks a "gnus-" prefix.
+(defvar total-parts)                    ;FIXME: Lacks a "gnus-" prefix.
+(defvar gnus-treat-type)
+(defvar gnus-treat-condition)
+(defvar gnus-treat-length)
+
+(defun gnus-treat-article (condition
+			   &optional part-num total type)
+  (let ((gnus-treat-condition condition)
+        (part-number part-num)
+        (total-parts total)
+        (gnus-treat-type type)
+        (gnus-treat-length (- (point-max) (point-min)))
 	(alist gnus-treatment-function-alist)
 	(article-goto-body-goes-to-point-min-p t)
 	(treated-type
-	 (or (not gnus-treat-type)
+	 (or (not type)
 	     (catch 'found
 	       (let ((list gnus-article-treat-types))
 		 (while list
-		   (when (string-match (pop list) gnus-treat-type)
+		   (when (string-match (pop list) type)
 		     (throw 'found t)))))))
 	(highlightp (gnus-visual-p 'article-highlight 'highlight))
-	val elem)
+	val)
     (gnus-run-hooks 'gnus-part-display-hook)
     (dolist (elem alist)
       (setq val
@@ -8626,13 +8639,6 @@ For example:
 	(save-restriction
 	  (funcall (cadr elem)))))))
 
-;; Dynamic variables.
-(defvar part-number)
-(defvar total-parts)
-(defvar gnus-treat-type)
-(defvar gnus-treat-condition)
-(defvar gnus-treat-length)
-
 (defun gnus-treat-predicate (val)
   (cond
    ((null val)
@@ -8881,7 +8887,7 @@ For example:
 	(gnus-mime-security-show-details handle)
       (gnus-mime-security-verify-or-decrypt handle))))
 
-(defun gnus-insert-mime-security-button (handle &optional displayed)
+(defun gnus-insert-mime-security-button (handle &optional _displayed)
   (let* ((protocol (mm-handle-multipart-ctl-parameter handle 'protocol))
 	 (gnus-tmp-type
 	  (concat
@@ -8929,7 +8935,7 @@ For example:
      :action 'gnus-widget-press-button
      :button-keymap gnus-mime-security-button-map
      :help-echo
-     (lambda (widget)
+     (lambda (_widget)
        ;; Needed to properly clear the message due to a bug in
        ;; wid-edit (XEmacs only).
        (when (boundp 'help-echo-owns-message)
diff --git a/lisp/mm-util.el b/lisp/mm-util.el
index 31b7d07..e40aece 100644
--- a/lisp/mm-util.el
+++ b/lisp/mm-util.el
@@ -1243,6 +1243,7 @@ evaluating FORMS but it is no longer done.  So, some programs assuming
 it if any may malfunction."
   (if (featurep 'xemacs)
       `(progn ,@forms)
+    (message "Warning: Using brain-dead macro `mm-with-unibyte-current-buffer'!")
     (let ((multibyte (make-symbol "multibyte")))
       `(let ((,multibyte enable-multibyte-characters))
 	 (when ,multibyte
@@ -1253,6 +1254,7 @@ it if any may malfunction."
 	     (set-buffer-multibyte t)))))))
 (put 'mm-with-unibyte-current-buffer 'lisp-indent-function 0)
 (put 'mm-with-unibyte-current-buffer 'edebug-form-spec '(body))
+(make-obsolete 'mm-with-unibyte-current-buffer nil "25.1")
 
 (defun mm-find-charset-region (b e)
   "Return a list of Emacs charsets in the region B to E."

-----------------------------------------------------------------------
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog   |   31 +++++++++++-
 lisp/gnus-art.el |  146 ++++++++++++++++++++++++++++--------------------------
 lisp/mm-util.el  |    2 +
 lisp/registry.el |    6 ++-
 4 files changed, 112 insertions(+), 73 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
diff --git a/lisp/registry.el b/lisp/registry.el
index 162e876..f0b3154 100644
--- a/lisp/registry.el
+++ b/lisp/registry.el
@@ -27,7 +27,7 @@
 
 ;; version: a float
 
 ;; max-size: an integer, default 5000000
 
 ;; prune-factor: a float between 0 and 1, default 0.1
 
@@ -110,7 +110,7 @@
             :type (or null float)
             :documentation "The registry version.")
    (max-size :initarg :max-size
-             :initform 5000000
+             ;; :initform most-positive-fixnum ;; see below
              :type integer
              :custom integer
              :documentation "The maximum number of registry entries.")
@@ -135,6 +135,8 @@
    (data :initarg :data
          :type hash-table
          :documentation "The data hashtable.")))
+;; Do this separately, since defclass doesn't allow expressions in :initform.
+(oset-default registry-db max-size most-positive-fixnum)
 
 (defmethod initialize-instance :BEFORE ((this registry-db) slots)
   "Check whether a registry object needs to be upgraded."
@@ -27,7 +27,7 @@
 ;; version: a float
 
-;; max-size: an integer, default 5000000
+;; max-size: an integer, default most-positive-fixnum
 
 ;; prune-factor: a float between 0 and 1, default 0.1

commit 2b20527a87e8e056ed22892bd6e0d249424a0403
Author: Stefan Monnier <[email protected]>
Date:   Thu Dec 18 22:37:00 2014 +0000

    * gnus-art.el: Fix up compiler warnings
    
    (article-display-face, article-display-x-face): Remove unused `face'.
    (gnus-article-browse-html-save-cid-content): Remove unused var `type'.
    (article-date-ut): Remove unused var `first'.
    (gnus-article-prepare): Remove unused var `gnus-article'.
    (gnus-mime-save-part-and-strip): Remove unused var `param'.
    (gnus-mime-inline-part): Remove unused vars `charset', `contents', and
    `coding-system' along with corresponding dead code.
    (gnus-mime-view-part-externally): Remove unused var
    `mm-user-display-methods'.
    (gnus-insert-mime-button): Let-bind gnus-tmp-id explicitly.
    (gnus-display-mime): Remove unused var `handle'.
    (gnus-mime-display-alternative): Remove unused var `props'.
    (gnus-article-read-summary-keys): Remove unused var `up-to-top'.
    (gnus-article-edit-done): Remove unused var `p'.
    (gnus-url-mailto): Remove unused var `to'.
    (gnus-treat-article): Let-bind gnus-treat-condition, part-number,
    total-parts, and gnus-treat-type explicitly.  Remove unused var `elem'.
    
    * mm-util.el (mm-with-unibyte-current-buffer): Mark obsolete and add warning.

-- 
Gnus Project